<?php

require_once(ABSPATH . 'wp-admin/includes/image.php');


class external_posts_Admin {

	private $plugin_name;
	private $version;

	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

        add_action('add_meta_boxes','external_posts_init_metaboxes');

        add_action( 'wp_ajax_external_posts_save', 'external_posts_save');

        add_action('template_redirect', 'external_posts_redirect' );

	}

	public function enqueue_styles() {
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/external-posts-admin.css', array(), $this->version, 'all' );
	}


	public function enqueue_scripts() {
		wp_enqueue_script($this->plugin_name."-admin", plugin_dir_url( __FILE__ ) . 'js/external-posts-admin.js', array( 'jquery' ), $this->version, false );
		wp_localize_script($this->plugin_name."-admin", 'ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' )) );
	}
}


function external_posts_init_metaboxes(){
    add_meta_box("external_post", "External post", "external_post", "post", "side", "low");
}


function external_post() {

    global $post;
    $external_url = get_post_meta($post->ID, 'external_url', true);
    $waiting_response = dirname(plugin_dir_url( __FILE__ )) . "/includes/images/waiting_response.gif";
    ?>

    <p><label><?php _e('External URL:', 'external-posts') ?></label><br />
    <div id='external_url_loading' style='display:none;'><img src=<?php echo $waiting_response; ?> height='40' width='40'></div>
    <textarea id='external_url' name="external_url"><?php echo $external_url; ?></textarea></p>
    <button id='external_post_submit' data-post-id='<?php echo $post->ID ?>'><?php _e('Submit', 'external-posts')?></button>

    <?php
}


function external_posts_save() {

    $external_url = filter_var($_POST['external_url'], FILTER_VALIDATE_URL);

    if ($external_url) { 

        $post_id = sanitize_text_field($_POST['post_id']);

        $thunbnail = '';
        $description = '';

        //Get all external data
        $ch = curl_init(); 
        curl_setopt($ch, CURLOPT_URL, $external_url); 
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        $output = curl_exec($ch);
        curl_close($ch);

        $doc = new DOMDocument();
        @$doc->loadHTML($output);
        $nodes = $doc->getElementsByTagName('title');
        $title = $nodes->item(0)->nodeValue;

        $metas = $doc->getElementsByTagName('meta');

        for ($i = 0; $i < $metas->length; $i++)
        {
            $meta = $metas->item($i);
            if($meta->getAttribute('property') == 'og:image')
                $thunbnail = $meta->getAttribute('content');
            if($meta->getAttribute('name') == 'description')
                $description = $meta->getAttribute('content');
        }

        $post = array(
            'ID' => $post_id,
            'post_title'    => $external_url,
            'post_content'  => $description,
            'post_status'   => 'draft',
            'post_title' => $title,

        );

        update_post_meta($post_id, 'external_url', $external_url);
     
        wp_insert_post($post);

        // Add Featured Image to Post
        if($thunbnail != '') {
            $image_url        = $thunbnail;
            $image_name       = substr($thunbnail, strrpos($thunbnail, '/'));
            $upload_dir       = wp_upload_dir();
            $image_data       = file_get_contents($image_url);
            $unique_file_name = wp_unique_filename($upload_dir['path'], $image_name);
            $filename         = basename($unique_file_name);

            // Check folder permission and define file location
            if(wp_mkdir_p($upload_dir['path'])) {
                $file = $upload_dir['path'] . '/' . $filename;
            } else {
                $file = $upload_dir['basedir'] . '/' . $filename;
            }

            file_put_contents($file, $image_data);

            $wp_filetype = wp_check_filetype($filename, null);

            // Set attachment data
            $attachment = array(
                'post_mime_type' => $wp_filetype['type'],
                'post_title'     => sanitize_file_name($filename),
                'post_content'   => '',
                'post_status'    => 'inherit'
            );

            $attach_id = wp_insert_attachment($attachment, $file, $post_id);

            $attach_data = wp_generate_attachment_metadata($attach_id, $file);
            wp_update_attachment_metadata($attach_id, $attach_data);

            set_post_thumbnail($post_id, $attach_id);
        }

        echo get_edit_post_link($post_id, 'none');
    }

    wp_die();
}


function external_posts_redirect() {
    $external_url = get_post_meta(get_the_ID(), 'external_url', true);
    if($external_url && is_single()) {
        wp_redirect($external_url);
        exit();
    }
}
